==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/DataSourceRowExpansionChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceRowExpansionChangedEventArgsDescription } from "./DataSourceRowExpansionChangedEventArgsDescription";
/**
 * @hidden
 */
var DataSourceRowExpansionChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataSourceRowExpansionChangedEventArgsDescriptionMetadata, _super);
    function DataSourceRowExpansionChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.b = function (a) {
        if (DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a == null) {
            DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataSourceRowExpansionChangedEventArgsDescriptionMetadata.c(DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a);
    };
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.d = function (a) {
        DataSourceRowExpansionChangedEventArgsDescriptionMetadata.b(a);
        a.ad("DataSourceRowExpansionChangedEventArgs", function () { return new DataSourceRowExpansionChangedEventArgsDescription(); });
        a.ac("DataSourceRowExpansionChangedEventArgs", DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a);
    };
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.$t = markType(DataSourceRowExpansionChangedEventArgsDescriptionMetadata, 'DataSourceRowExpansionChangedEventArgsDescriptionMetadata');
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a = null;
    return DataSourceRowExpansionChangedEventArgsDescriptionMetadata;
}(Base));
export { DataSourceRowExpansionChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/DataSourceRowExpansionChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceRowExpansionChangedEventArgsDescription } from "./DataSourceRowExpansionChangedEventArgsDescription";
/**
 * @hidden
 */
var DataSourceRowExpansionChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataSourceRowExpansionChangedEventArgsDescriptionMetadata, _super);
    function DataSourceRowExpansionChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.b = function (a) {
        if (DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a == null) {
            DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataSourceRowExpansionChangedEventArgsDescriptionMetadata.c(DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a);
    };
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.d = function (a) {
        DataSourceRowExpansionChangedEventArgsDescriptionMetadata.b(a);
        a.ae("DataSourceRowExpansionChangedEventArgs", function () { return new DataSourceRowExpansionChangedEventArgsDescription(); });
        a.ad("DataSourceRowExpansionChangedEventArgs", DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a);
    };
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.$t = markType(DataSourceRowExpansionChangedEventArgsDescriptionMetadata, 'DataSourceRowExpansionChangedEventArgsDescriptionMetadata');
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a = null;
    return DataSourceRowExpansionChangedEventArgsDescriptionMetadata;
}(Base));
export { DataSourceRowExpansionChangedEventArgsDescriptionMetadata };
